@@ -10,9 +10,9 @@
 
 from loguru import logger
 
-from .conv_evaluator import ConvEvaluator
-from .rec_evaluator import RecEvaluator
-from .standard_evaluator import StandardEvaluator
+from .conv import ConvEvaluator
+from .rec import RecEvaluator
+from .standard import StandardEvaluator
 from ..data import dataset_language_map
 
 Evaluator_register_table = {
@@ -22,13 +22,13 @@ Evaluator_register_table = {
 }
 
 
-def get_evaluator(evaluator_name, dataset):
+def get_evaluator(evaluator_name, dataset, tensorboard=False):
     if evaluator_name in Evaluator_register_table:
         if evaluator_name in ('conv', 'standard'):
             language = dataset_language_map[dataset]
-            evaluator = Evaluator_register_table[evaluator_name](language)
+            evaluator = Evaluator_register_table[evaluator_name](language, tensorboard=tensorboard)
         else:
-            evaluator = Evaluator_register_table[evaluator_name]()
+            evaluator = Evaluator_register_table[evaluator_name](tensorboard=tensorboard)
         logger.info(f'[Build evaluator {evaluator_name}]')
         return evaluator
     else:
