@@ -8,14 +8,12 @@
 # @Email  : francis_kun_zhou@163.com, wxl1999@foxmail.com
 
 from loguru import logger
+import torch
 
 from .conversation import *
-from .kbrd import *
-from .kgsf import *
+from .crs import *
 from .policy import *
 from .recommendation import *
-from .redial import *
-from .tgredial import *
 
 Model_register_table = {
     'KGSF': KGSFModel,
@@ -25,6 +23,8 @@ Model_register_table = {
     'TGPolicy': TGPolicyModel,
     'ReDialRec': ReDialRecModel,
     'ReDialConv': ReDialConvModel,
+    'InspiredRec': InspiredRecModel,
+    'InspiredConv': InspiredConvModel,
     'GPT2': GPT2Model,
     'Transformer': TransformerModel,
     'ConvBERT': ConvBERTModel,
@@ -44,6 +44,13 @@ def get_model(config, model_name, device, vocab, side_data=None):
     if model_name in Model_register_table:
         model = Model_register_table[model_name](config, device, vocab, side_data)
         logger.info(f'[Build model {model_name}]')
-        return model
+        if config.opt["gpu"] == [-1]:
+            return model
+        else:
+            if len(config.opt["gpu"]) > 1 and model_name == 'PMI':
+                logger.info(f'[PMI model does not support multi GPUs yet, using single GPU now]')
+                return model.to(device)
+            return torch.nn.DataParallel(model, device_ids=config["gpu"])
+
     else:
         raise NotImplementedError('Model [{}] has not been implemented'.format(model_name))
